summaryrefslogtreecommitdiff
path: root/lisp/window.el
diff options
context:
space:
mode:
authorMartin Rudalics <rudalics@gmx.at>2008-06-10 07:45:23 +0000
committerMartin Rudalics <rudalics@gmx.at>2008-06-10 07:45:23 +0000
commit71b50c9351b445b7d2d7eae0c9cfe906532fcdb6 (patch)
tree16f4306a535dae29ab44056ebd1342c05d1f5257 /lisp/window.el
parentfaeb9c70aeb74dc9b27a40c2d3b158e01b9e1235 (diff)
downloademacs-71b50c9351b445b7d2d7eae0c9cfe906532fcdb6.tar.gz
(window--splittable-p, window--try-to-split-window):
Don't use with-selected-window to avoid messing up get-lru-window.
Diffstat (limited to 'lisp/window.el')
-rw-r--r--lisp/window.el14
1 files changed, 7 insertions, 7 deletions
diff --git a/lisp/window.el b/lisp/window.el
index 74c7a366f0f..3cdc99e2651 100644
--- a/lisp/window.el
+++ b/lisp/window.el
@@ -806,7 +806,7 @@ hold:
- When WINDOW is split evenly, the emanating windows are at least
`window-min-width' or two (whichever is larger) columns wide."
(when (window-live-p window)
- (with-selected-window window
+ (with-current-buffer (window-buffer window)
(if horizontal
;; A window can be split horizontally when its width is not
;; fixed, it is at least `split-width-threshold' columns wide
@@ -847,11 +847,11 @@ by `split-window' or `split-window-preferred-function'."
(and (window--splittable-p window t)
;; Split window horizontally.
(split-window window nil t))
- (and (with-selected-window window
- (one-window-p 'nomini))
- ;; If WINDOW is the only window on its frame, attempt to
- ;; split it vertically disregarding the current value of
- ;; `split-height-threshold'.
+ (and (eq window (frame-root-window (window-frame window)))
+ (not (window-minibuffer-p window))
+ ;; If WINDOW is the only window on its frame and not the
+ ;; minibuffer window, attempt to split it vertically
+ ;; disregarding the value of `split-height-threshold'.
(let ((split-height-threshold 0))
(window--splittable-p window)
(split-window window)))))))
@@ -1013,7 +1013,7 @@ consider all visible or iconified frames."
(setq frame-to-use (last-nonminibuffer-frame))
(window--frame-usable-p frame-to-use)
(not (frame-parameter frame-to-use 'unsplittable))))
- ;; Attempt to split largest or most recently used window.
+ ;; Attempt to split largest or least recently used window.
(setq window-to-use
(or (window--try-to-split-window
(get-largest-window frame-to-use t))